==> haskell-semigroups-0.18.1-1-armv7h.pkg.tar.xz: usr/share/haskell/haskell-semigroups/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: semigroups
version: 0.18.1
id: semigroups-0.18.1-34c490e60d2f8a8cae75b79e944c6c08
key: semig_BISg3KdVHgi6d0bJ8lTz2h
license: BSD3
copyright: Copyright (C) 2011-2015 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: provisional
homepage: http://github.com/ekmett/semigroups/
synopsis: Anything that associates
description:
    In mathematics, a semigroup is an algebraic structure consisting of a set together with an associative binary operation. A semigroup generalizes a monoid in that there might not exist an identity element. It also (originally) generalized a group (a monoid with all inverses) to a type where every element did not have to have an inverse, thus the name semigroup.
category: Algebra, Data, Data Structures, Math
author: Edward A. Kmett
exposed: True
exposed-modules:
    Data.Semigroup.Generic Data.Semigroup Data.List.NonEmpty
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/semigroups-0.18.1
library-dirs: /usr/lib/ghc-7.10.3/site-local/semigroups-0.18.1
data-dir: /usr/share/arm-linux-ghc-7.10.3/semigroups-0.18.1
hs-libraries: HSsemigroups-0.18.1-BISg3KdVHgi6d0bJ8lTz2h
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    binary-0.7.5.0-29f7044fa0b12dc5c2dcec897db5c464
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    deepseq-1.4.1.1-3975618f889b45239daa47b7443eaeee
    hashable-1.2.4.0-f83fcc5c92d0a1ea59927aca6baa3161
    tagged-0.8.3-aa128de4449752177a05765fb0ce3959
    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    unordered-containers-0.2.6.0-2907cc2989779dea3b04f8a0a144a8a7
haddock-interfaces: /usr/share/doc/haskell-semigroups/html/semigroups.haddock
haddock-html: /usr/share/doc/haskell-semigroups/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-semigroups-0.18.1-2-armv7h.pkg.tar.xz: usr/share/haskell/haskell-semigroups/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: semigroups
version: 0.18.1
id: semigroups-0.18.1-4a4dee25d838ab8c8d38a0caa045cf78
key: semig_CagRMnHyiUMJkufMZJJSR4
license: BSD3
copyright: Copyright (C) 2011-2015 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: provisional
homepage: http://github.com/ekmett/semigroups/
synopsis: Anything that associates
description:
    In mathematics, a semigroup is an algebraic structure consisting of a set together with an associative binary operation. A semigroup generalizes a monoid in that there might not exist an identity element. It also (originally) generalized a group (a monoid with all inverses) to a type where every element did not have to have an inverse, thus the name semigroup.
category: Algebra, Data, Data Structures, Math
author: Edward A. Kmett
exposed: True
exposed-modules:
    Data.Semigroup.Generic Data.Semigroup Data.List.NonEmpty
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/semigroups-0.18.1
library-dirs: /usr/lib/ghc-7.10.3/site-local/semigroups-0.18.1
data-dir: /usr/share/arm-linux-ghc-7.10.3/semigroups-0.18.1
hs-libraries: HSsemigroups-0.18.1-CagRMnHyiUMJkufMZJJSR4
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    binary-0.7.5.0-29f7044fa0b12dc5c2dcec897db5c464
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    deepseq-1.4.1.1-3975618f889b45239daa47b7443eaeee
    hashable-1.2.4.0-f83fcc5c92d0a1ea59927aca6baa3161
    tagged-0.8.3-aa128de4449752177a05765fb0ce3959
    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    unordered-containers-0.2.7.0-03f1d2fb96e30aca19bb1467e9476c22
haddock-interfaces: /usr/share/doc/haskell-semigroups/html/semigroups.haddock
haddock-html: /usr/share/doc/haskell-semigroups/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
